``jupyterlab`` pack - JupyterLab interface
==========================================

The ``jupyterlab`` pack installs and enables the `JupyterLab <https://jupyterlab.readthedocs.io/en/stable/getting_started/overview.html>`_ interface (v3.x).

To enable the pack, add it to the ``packs`` key as follows:

.. code:: yaml

    packs:
      - name: jupyterlab

The pack does not have any configuration options.
